@@ -169,7 +169,7 @@ char usage[] =
 char askhelp[] = "Type sabcmd --help to display a help message.\n";
 char msgConflict[] = "conflict with preceding switches: ";
 char version_txt[] = "\nsabcmd "SAB_VERSION" ("SAB_DATE")\n"\
-    "copyright (C) 2000 - 2004 Ginger Alliance (www.gingerall.com)\n";
+    "copyright (C) 2000 - 2005 Ginger Alliance (www.gingerall.com)\n";
 char dbg_usage[] = "\nDebugging options:\n"\
     "\t--debug\t\t\tdisplay results of the command line parse\n"\
     "\t--debugger\t\trun the xslt debugger\n"\
@@ -211,7 +211,7 @@ void saberrn(const char *msg, int num)
 
 int chrpos(const char *text, char c)
 {
-    char *p = strchr(text, c);
+    const char *p = strchr(text, c);
     return p ? (int)(p - text) : -1;
 }
 
